<?php $__env->startSection('content'); ?>
   <!-- Bootstrap CSS -->
   <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.css" />


    <!-- Daterangepicker JS -->
    <script src="https://cdn.jsdelivr.net/momentjs/latest/moment.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.min.js"></script>

<?php if(session('url')): ?>
    <script>
        var url = "<?php echo session('url'); ?>";
        var win = window.open(url, '_blank', 'noopener,noreferrer');
        win.opener = null; // Evita que la nueva ventana tenga una referencia al objeto del navegador actual
        win.focus(); // Pone el foco en la nueva ventana
    </script>
<?php endif; ?>
 <!-- content -->
<div class="titulos"> 

  <?php if (! (empty($datosDelCliente))): ?>
       <h2>Datos personales  </h2>

  <?php else: ?>

    <h2>Ordenes de trabajo  </h2>

    <?php endif; ?>

    <hr />

</div>


<style>
  .error {
    border: 1px solid red;  /* Add a red border to indicate the error */
}
</style>



<?php if (! (empty($datosDelCliente))): ?>


    <div class="row">

          <div class="mb-3 col-6" >
            <label for="razon_social" class="form-label">Razon social</label>
            <input type="text" required class="form-control" id="razon_social" placeholder=""  disabled   value="<?php echo e(old('sku', isset($datosDelCliente[0]->razon_social) ? $datosDelCliente[0]->razon_social : '')); ?>"  name="razon_social">
            <?php $__errorArgs = ['razon_social'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
            <div class="alert alert-danger"><?php echo e($message); ?></div>
            <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
          </div>

          <div class="col-md m-2">
            <label for="">Rut</label>
            <input type="text" class="form-control" disabled value="<?php echo e(old('rut', isset($datosDelCliente[0]->rut) ? $datosDelCliente[0]->rut : '')); ?>"  name="contacto_rut"
                id="contacto_rut">
            <span id="rut_span" style="display: none"><label for=""
                    id="error_rut"></label></span>
                    <label id="l_contacto_rut" style="display: none; color: red" for="">Campo obligatorio</label>

          </div>
            <div class="mb-3  col-6">
              <label for="giro" class="form-label">Giro</label>
              <input type="text"  class="form-control" id="giro" placeholder=""  disabled value="<?php echo e(old('giro', isset($datosDelCliente[0]->giro) ? $datosDelCliente[0]->giro : '')); ?>" name="giro">
              <?php $__errorArgs = ['giro'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
            <div class="alert alert-danger"><?php echo e($message); ?></div>
            <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>


          </div>
          <div class="mb-3 col-6" >
            <label for="telefono" class="form-label">Telefono</label>
            <input type="text" required class="form-control" id="telefono" placeholder="" disabled value="<?php echo e(old('telefono', isset($datosDelCliente[0]->telefono) ? $datosDelCliente[0]->telefono : '')); ?>" name="telefono">
            <?php $__errorArgs = ['telefono'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
          <div class="alert alert-danger"><?php echo e($message); ?></div>
          <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>


          </div>
          <div class="mb-3  col-6">
            <label for="correo" class="form-label">Correo</label>
            <input type="email"  class="form-control" id="correo" placeholder=""   disabled value="<?php echo e(old('correo', isset($datosDelCliente[0]->correo) ? $datosDelCliente[0]->correo : '')); ?>" name="correo">
            <?php $__errorArgs = ['correo'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
            <div class="alert alert-danger"><?php echo e($message); ?></div>
            <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>

          </div>
          <div class="mb-3 col-6" >
            <label for="direccion" class="form-label">Direccion</label>
            <input type="text" required class="form-control" id="direccion" placeholder=""    disabled value="<?php echo e(old('direccion', isset($datosDelCliente[0]->nombre_direccion) ? $datosDelCliente[0]->nombre_direccion : '')); ?>" name="direccion">
            <?php $__errorArgs = ['direccion'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
            <div class="alert alert-danger"><?php echo e($message); ?></div>
            <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
          </div>

          <div class="mb-3 col-6" >
            <label for="direccion" class="form-label">Región</label>
            <input type="text" required class="form-control" id="direccion" placeholder=""    disabled value="<?php echo e(old('direccion', isset($datosDelCliente[0]->des_region) ? $datosDelCliente[0]->des_region : '')); ?>" name="direccion">
            <?php $__errorArgs = ['direccion'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
            <div class="alert alert-danger"><?php echo e($message); ?></div>
            <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
          </div>  <div class="mb-3 col-6" >
            <label for="direccion" class="form-label">Comuna</label>
            <input type="text" required class="form-control" id="direccion" placeholder=""    disabled value="<?php echo e(old('direccion', isset($datosDelCliente[0]->des_comuna) ? $datosDelCliente[0]->des_comuna : '')); ?>" name="direccion">
            <?php $__errorArgs = ['direccion'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
            <div class="alert alert-danger"><?php echo e($message); ?></div>
            <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
          </div>
        
    </div>
<?php endif; ?>

<?php if(session('mensaje')): ?>
    <div class="alert alert-success">
        <?php echo e(session('mensaje')); ?>

    </div>
<?php endif; ?>
 <div class="container-fluid botones-extremo " >
  
</div> 
<?php if (! (empty($datosDelCliente))): ?>
    <div class="container-fluid botones-extremo " >
      <hr>
      <div class="d-flex justify-content-between">
         <h5>Ordenes de trabajo</h5>
        
      </div>
    </div>

<?php else: ?>


  <?php if(\App\Models\User::tipoUsuario() != "operario"): ?>

      <div class="container-fluid botones-extremo " >
        <div class="d-flex justify-content-between">
            <a href="<?php echo e(route('ot.crearsincliente')); ?>" class=" btn  btn-success" title="" >Nuevo</a>
          
        </div>
      </div>
  <?php endif; ?>

<?php endif; ?>

    <div class="row">
      <form action="<?php echo e(route('filtrarOt.ot')); ?>" method="GET" class="row" style="margin-left: 4px">

        <?php echo csrf_field(); ?>

        <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin"): ?>

              <div class="col-3"> 

                <label for="">Sucursal</label>
                <select  class="form-control" name="sucursales" id="selecionar_sucursal">

                  <option value="">Seleccionar</option>
                  <?php if(!empty($sucursales)): ?>
                            <?php $__currentLoopData = $sucursales; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $data): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                            <?php if(!empty($req->sucursales )): ?>

                                <?php if($data->id == $req->sucursales ?? ''): ?>
                                <option selected value="<?php echo e($data->id); ?>" <?php echo e((old('sucursal')==$data->id)? 'selected':''); ?>><?php echo e($data->descripcion); ?></option>
                                <?php else: ?>
                                <option  value="<?php echo e($data->id); ?>" <?php echo e((old('sucursal')==$data->id)? 'selected':''); ?>><?php echo e($data->descripcion); ?></option>

                                <?php endif; ?>
                                <?php else: ?>
                                <option  value="<?php echo e($data->id); ?>" <?php echo e((old('sucursal')==$data->id)? 'selected':''); ?>><?php echo e($data->descripcion); ?></option>

                                <?php endif; ?>



                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                            <?php endif; ?>
          
                </select>
              </div>
      <?php endif; ?>

    <!-- FECHA -->
    <div class="form-group col-md-3">
      <label for="">Fechas</label>

          <!-- <label for="dateRangeSelect">Rango de Fecha</label> -->
          <input style="cursor: pointer" type="text" class="form-control" id="customDateRange" name="customDateRange"
          value="<?php echo htmlspecialchars($_GET['customDateRange'] ?? ''); ?>">
   
          <input type="date" hidden class="form-control"  id="fecha_inicio" name="fecha_inicio">
          <input type="date" hidden class="form-control"  id="fecha_fin" name="fecha_fin">

      </div>


      
      <div class="form-group col-md-3">
        <label for="">Estados</label>
  
        <select  class="form-control" name="estados" id="estados">

          <option value="">Seleccionar</option>
          <?php if(!empty($estados_ot)): ?>
                    <?php $__currentLoopData = $estados_ot; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $data): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                    <?php if(!empty($req->estados )): ?>

                        <?php if($data->id == $req->estados ?? ''): ?>
                        <option selected value="<?php echo e($data->id); ?>" <?php echo e((old('estados')==$data->id)? 'selected':''); ?>><?php echo e($data->descripcion); ?></option>
                        <?php else: ?>
                        <option  value="<?php echo e($data->id); ?>" <?php echo e((old('estados')==$data->id)? 'selected':''); ?>><?php echo e($data->descripcion); ?></option>

                        <?php endif; ?>
                        <?php else: ?>
                        <option  value="<?php echo e($data->id); ?>" <?php echo e((old('estados')==$data->id)? 'selected':''); ?>><?php echo e($data->descripcion); ?></option>

                        <?php endif; ?>



                    <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                    <?php endif; ?>
            </select>
  
        </div>
                
          
          
          
          
          <div class="col-3"> 
        <br>
        <button type="submit" class="btn btn-success">Filtrar</button> 
      <button type="button" class="btn btn-primary" onclick="exportardata()" >Exportar</button>
      <button style="color: white" type="button" class="btn btn-info" onclick="imprimirData()" >Imprimir</button>

      </form>
      
  </div>
</div>




 <div class="container-fluid table-responsive">
    <div class="row">
        <div class="col bttn-buscar">
            <input type="text" class="form-control" id="buscarData" placeholder="Buscar">
        </div>
    </div><br>
   <div style="text-align: right">
    

      
   </div>
    
   <div  style=" display: none  ;text-align: right; cursor: pointer; margin-right: 15px;">
    <a >
      <span class="material-symbols-outlined" onclick="imprimirData()" >print</span>
  </a>
   </div>
    <div class="table-responsive mb-5">
        <table class="table table-striped table-hover" id="mitable">
          <thead class="color-head">
            
            <tr>
              <th class="th-subhead border-th">Id</th>

              <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin"): ?>
                <th class="th-subhead border-th">Sucursal</th>
              <?php endif; ?>

              <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>
              <th class="th-subhead border-th">Contacto</th>
              <th class="th-subhead border-th" style="width: 100px;">Rut</th>
              <th class="th-subhead border-th" style="width: 100px;">Motor</th>

              <th class="th-subhead border-th">Operario encargado</th>
              <th class="th-subhead border-th"  style="width: 150px;" >Total</th>
              <?php endif; ?>


              <?php if(\App\Models\User::tipoUsuario() == "operario" ): ?>
                    <th class="th-subhead border-th separador-v">Marca</th>
                    <th class="th-subhead border-th separador-v">Modelo</th>
                    <th class="th-subhead border-th separador-v">Motor</th>
                    <th class="th-subhead border-th separador-v">Año</th>
                    <th class="th-subhead border-th separador-v">Combustible</th>
              <?php endif; ?>

              <th class="th-subhead border-th separador-v">Fecha ingreso</th>
              <th class="th-subhead border-th">Fecha entrega</th>
              <th class="th-subhead border-th separador-v">Estado</th>

              <th class="th-subhead border-th">Acción</th>
              
              <th class="th-subhead border-th"></th>
            </tr>
          </thead>
          
          <tbody id="tableOt"></tbody>
          <tbody id="tableOtGeneral">

            <tr>
                
                
                
              </tr>
              
              

              
            <?php if(!empty($ordenesdetrabajo)): ?>
             <?php $__currentLoopData = $ordenesdetrabajo; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $los_datos): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>

              <tr>


                

                <td class="td-val"><?php echo e($los_datos->numero_ot); ?></td>
              <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin"): ?>
                <td class="td-val"><?php echo e($los_datos->nombre_sucursal); ?></td>
              <?php endif; ?>

              <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>
                    <td class="td-val"><?php echo e($los_datos->razon_social); ?></td>
                    <td class="td-val"><?php echo e($los_datos->rut); ?></td>

                    <td class="td-val">
                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->marca); ?>

                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->modelo); ?>

                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->motor); ?>

                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->ano); ?>

                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->nombrecombustible); ?>



                    </td>

                    <td class="td-val"><?php echo e($los_datos->nombre_completo); ?></td>

              <?php endif; ?>


              <?php if(\App\Models\User::tipoUsuario() == "operario" ): ?>
              <td class="td-val"><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->marca); ?></td>
              <td class="td-val"><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->modelo); ?></td>
              <td class="td-val"><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->motor); ?></td>
              <td class="td-val"><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->ano); ?></td>
              <td class="td-val"><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->nombrecombustible); ?></td>

              <?php endif; ?>

              <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>

              <td class="td-val">$
              <?php echo e(number_format($los_datos->total_con_descuentos, 0, ',', '.')); ?>

              </td>
              <?php endif; ?>

                <td class="td-val">
                  
                  <?php echo e(Carbon\Carbon::createFromDate($los_datos->fecha_ingreso?? '')->format('d-m-Y')); ?>

                  
                
                </td>
                <td class="td-val">
                  

                  <?php if($los_datos->fecha_entrega != ""): ?>
                  <?php echo e(Carbon\Carbon::createFromDate($los_datos->fecha_entrega ?? '')->format('d-m-Y')); ?>

                  <?php endif; ?>
                
                </td>
                
                <td class="td-val"><?php echo e($los_datos->descripcionestado); ?></td>


                <?php if( $los_datos->descripcionestado== "PRESUPUESTO"): ?> 

                <td class="td-val">
                  <a href="<?php echo e(route('ordendetrabajo.show', ['id' => $los_datos->id])); ?>" >
                    <span class="material-symbols-outlined" style="cursor:pointer" title="Completa OT">
                      visibility
                      </span>
                  </a>
                  <span class="material-symbols-outlined" style="cursor:pointer" title="Historial OT"  onclick="abrirModal(<?php echo e($los_datos->numero_ot); ?>)" >
                    manage_search
                    </span>
                </td>

                <?php else: ?>
                          <td class="td-val">

                            
                            <?php if($los_datos->descripcionestado == "FACTURADA" || $los_datos->descripcionestado == "CANCELADA" ): ?>

                                    <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin"): ?>

                                          <a href="<?php echo e(route('ordendetrabajo.showhistorial', ['id' => $los_datos->id])); ?>" >
                                            <span class="material-symbols-outlined">
                                              visibility
                                              </span>
                                          </a>

                                          
                                    <?php endif; ?>
                            <?php else: ?>
                            <a href="<?php echo e(route('ordendetrabajo.show', ['id' => $los_datos->id])); ?>" >
                              <span class="material-symbols-outlined" style="cursor:pointer" title="Completa OT">
                                visibility
                                </span>
                            </a>
                            
                           
                            <?php endif; ?>

                            


                            <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>

                                    <a>
                                      
                                      </a>


                                      <?php if($los_datos->descripcionestado != "FACTURADA"  ): ?>

                                        <a href="<?php echo e(route('ordendetrabajo.editar', ['id' => $los_datos->id])); ?>" >
                                            <span class="material-symbols-outlined" style="cursor:pointer" title="Editar">
                                              edit
                                              </span>
                                        </a>
                                        <?php else: ?>

                                        
                                       <?php endif; ?> 

                                      <span class="material-symbols-outlined" style="cursor:pointer" title="Historial OT"  onclick="abrirModal(<?php echo e($los_datos->numero_ot); ?>)" >
                                      manage_search
                                      </span>

                                      
                                      <span class="material-symbols-outlined" style="cursor:pointer" title="Abonos" onclick="abrirModalAbonos(<?php echo e($los_datos->numero_ot); ?>,<?php echo e($los_datos->id); ?>)">
                                      paid
                                      </span>

                                <?php endif; ?>
                          </td>

                      <?php endif; ?>
                      <td>

                        <?php if($los_datos->descripcionestado ==  "RECEPCIONADA"  ): ?>
                        <a href="<?php echo e(route('ordendetrabajo.iniciarget', ['id' => $los_datos->id])); ?>" class="material-symbols-outlined" style="cursor:pointer" title="Iniciar OT" onclick="return confirm('¿Estás seguro de que deseas iniciar esta OT : <?php echo e($los_datos->numero_ot); ?> ?')">
                          play_arrow
                      </a>

                        <?php elseif($los_datos->descripcionestado ==  "INICIADA"  ): ?>
                       
                        <a href="<?php echo e(route('ordendetrabajo.finalizarget', ['id' => $los_datos->id])); ?>" class="material-symbols-outlined" style="cursor:pointer" title="Finalizar OT" onclick="return confirm('¿Estás seguro de que deseas finalizar esta OT: <?php echo e($los_datos->numero_ot); ?>?')">
                          stop_circle
                      </a>
                        
                        
                        <?php else: ?>

                        <?php endif; ?>

                      </td>
                       

                
                
              </tr>
            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?> 

            <?php endif; ?>
          </tbody>
        </table>
        
         <?php echo e($ordenesdetrabajo->appends(request()->query())->links('pagination::bootstrap-4')); ?>


      </div>
      

    

</div>

 <!-- Modal Tecnico -->
 <div class="modal" id="modalHistorial">
  <div class="modal-dialog"> 
      <div class="modal-content">

          <!-- Modal Header -->
          <div class="modal-header">
              <h4 class="modal-title">Historial</h4>
              <button type="button" class="btn-close" onclick="cerrarModal()"></button>


          </div>

          <!-- Modal body -->
          <div class="modal-body">

            <table class="table table-hover">
              <thead class="bg-light">
                  
                  <th scope="col">#</th>

                  <th scope="col">Fecha Ingresada</th>
                  <th scope="col">Ver</th>
                  <th scope="col">Pdf</th>



              </thead>
              
              <tbody id="tabla_servicios_selecionados">

                  

              </tbody>

          </table>  
                </div>
      </div>
  </div>




</div>

   <!-- Modal historial abonos -->
   <div class="modal" id="modalHistorialAbonos">
    <div class="modal-dialog"> 
        <div class="modal-content">
  
            <!-- Modal Header -->
            <div class="modal-header">
                <h4 class="modal-title">Historial</h4>
                <button type="button" class="btn-close" onclick="cerrarModalAbonos()"></button>
  
  
            </div>
  
            <!-- Modal body -->
            <div class="modal-body">

              <div class="container" >

                <div class="row">

                  <div class="col-4">
                    <label for="">Medio de pago</label>
                    <select name="" class="form-control" id="mediosPagosSelect">
                        <option value="">SELECCIONAR</option>
                        <?php if(!empty($medios_pagos)): ?>
                            <?php $__currentLoopData = $medios_pagos; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $data): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
                                <option value="<?php echo e($data->id); ?>"
                                    <?php echo e(old('modopago') == $data->id ? 'selected' : ''); ?>><?php echo e(strtoupper($data->descripcion)); ?>

                                    </option>
                            <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
                        <?php endif; ?>
                    </select>
                  </div>
                  <div class="col-4">
                    <label for="">Monto</label>

                    <input type="text" class="form-control" oninput="permitirSoloNumeros(this)" id="montoparaabonar"> 
                  </div>
                  <div class="col-4 mt-4" >
                    <input type="button" class="btn btn-success" onclick="agregarabono()"  value="Agregar">
                  </div>
                </div>

                <div class="row mt-5">

                  <label for="ltotaladeudado" id="ltotaladeudado" style="display: inline; margin-left: 5px;"></label>

                  <table class="table table-hover">
                    <thead class="bg-light">
                        
      
                        <th scope="col">Fecha Ingresada</th>
                        <th scope="col">Metodo pago</th>
                        <th scope="col">Total</th>

      
      
                    </thead>
                    
                    <tbody id="table_historia_abonos">
      
                        
      
                    </tbody>
      
                </table>  
                </div>

              </div>
  
            
            </div>
        </div>
    </div>
  </div>
<script>

var numeroDelaOtGlobal = "";
var idOtGlobal = "";
var totalAdeudadoGlobal = "";



function imprimirData(){


// VALIDAR OTRO TIPO FECHA

// if($("#fecha_inicio").val() == "" || $("#fecha_fin").val() == ""){
//   response = false;
// }else{
//   response = validarDiferenciaAno("#fecha_inicio","#fecha_fin");

// }
response = false;

// alert(response);
        if(response == true){
            //mayor a un años
            
        }else{

        console.log("hola");
        var parametro1 = $("#fecha_inicio").val();
                    var parametro2 = $("#fecha_fin").val();
                    var parametro3 = $("#selecionar_sucursal").val();
                    var parametro4 = $("#estados").val();

                    var urlConParametros = '/imprimir/ordenesdetrabajo?fecha_inicio=' + encodeURIComponent(parametro1)
                    + '&fecha_fin=' + encodeURIComponent(parametro2)+ '&sucursal=' + encodeURIComponent(parametro3)+ '&estados=' + encodeURIComponent(parametro4);

                    // Abrir la nueva ventana o pestaña con la URL construida
                    window.open(urlConParametros, '_blank');

          }

}


function exportardata(){


// if($("#fecha_inicio").val() == "" || $("#fecha_fin").val() == ""){
//   response = false;
// }else{
//   response = validarDiferenciaAno("#fecha_inicio","#fecha_fin");

// }

response = false;
        if(response == true){
            //mayor a un años
            
        }else{

            var parametro1 = $("#fecha_inicio").val();
            var parametro2 = $("#fecha_fin").val();
            var parametro3 = $("#selecionar_sucursal").val();
            var parametro4 = $("#estados").val();

            var urlConParametros = '/exportar/ordenesdetrabajo?fecha_inicio=' + encodeURIComponent(parametro1)
             + '&fecha_fin=' + encodeURIComponent(parametro2)+ '&sucursal=' + encodeURIComponent(parametro3)+ '&estados=' + encodeURIComponent(parametro4);

            // Abrir la nueva ventana o pestaña con la URL construida
            window.open(urlConParametros, '_blank');

        }

// console.log(response);


    }

function agregarabono(){

  mediosPagosSelect = $("#mediosPagosSelect").val();
  montoparaabonar = $("#montoparaabonar").val();


    // Check if any of the values is null or empty
    if (!mediosPagosSelect || !montoparaabonar) {
        // Add a red border to the input fields
        if (!mediosPagosSelect) {
            $("#mediosPagosSelect").addClass("error");
        }
        if (!montoparaabonar) {
            $("#montoparaabonar").addClass("error");
        }

        // alert('Please fill in all required fields.');
        return; // Exit the function if validation fails
    }

    if(montoparaabonar > totalAdeudadoGlobal){
      return;
    }
    // Remove the red border if validation passes
    $("#mediosPagosSelect").removeClass("error");
    $("#montoparaabonar").removeClass("error");


  $.ajax({
               
               headers: {
                   'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
               },
               type: 'POST',
               url: "<?php echo e(route('ordendetrabajo.addabono')); ?>",
               data: {
                   'mediosPagosSelect': mediosPagosSelect,
                   'montoparaabonar': montoparaabonar,
                   'numeroDelaOtGlobal': numeroDelaOtGlobal,
                   'idOtGlobal': idOtGlobal,



                   
                  
               },
               success: function(data) {
                                   var totalabonos = 0;

               $('#modalHistorialAbonos').show();
                   console.log(data);
                   $('#table_historia_abonos').empty();

                   $.each(data.pagos, function(index, objeto) {




                  var tr = "<tr>";
                //          // tr += "<td>" + objeto.id + "</td>";
                        tr += "<td>" + (formatearFecha(objeto.fecha) || '') + "</td>";
                        tr += "<td>" + (objeto.descripcion.toUpperCase() || '') + "</td>";
                        tr += "<td>" + "$"+(format_js(objeto.total) || '') + "</td>";

                  
                        
                        tr += "</tr>";

                        totalabonos = totalabonos+ objeto.total;

                         $('#table_historia_abonos').append(tr);



                        });
                        var trt = "<tr>";
                          trt += "<td></td>";
                          trt += "<td></td>";
                          trt += "<td >" +"$"+ (format_js(totalabonos) || '') + "</td>";
                          trt += "</tr>";
                        $('#table_historia_abonos').append(trt);
                        $("#ltotaladeudado").css("display", "inline").text("Total adeudado: $"+format_js(data.adeudado));
                        totalAdeudadoGlobal  = data.adeudado;

                        
                },
                error: function(xhr, status) {
                   alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
               }
           });

}

function abrirModalAbonos(numeroDelaOt,idOt){
  numeroDelaOtGlobal = numeroDelaOt;
  idOtGlobal = idOt;



  $.ajax({
               
               headers: {
                   'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
               },
               type: 'POST',
               url: "<?php echo e(route('ordendetrabajo.abonos')); ?>",
               data: {
                   'numerodelaot': numeroDelaOt,
                   'idOt': idOt,

                  
               },
               success: function(data) {
               $('#modalHistorialAbonos').show();
               $('#table_historia_abonos').empty();

                   console.log("datadatadata");
                   console.log(data);
                   var totalabonos = 0;
                 $.each(data.pagos, function(index, objeto) {




                        var tr = "<tr>";
                //          // tr += "<td>" + objeto.id + "</td>";
                        tr += "<td>" + (formatearFecha(objeto.fecha) || '') + "</td>";
                        tr += "<td>" + (objeto.descripcion.toUpperCase() || '') + "</td>";
                        tr += "<td>" + "$"+(format_js(objeto.total) || '') + "</td>";

                  
                        
                        tr += "</tr>";

                        totalabonos = totalabonos+ objeto.total;

                         $('#table_historia_abonos').append(tr);



                        });
                        var trt = "<tr>";
                          trt += "<td></td>";
                          trt += "<td></td>";
                          trt += "<td >" + "$"+(format_js(totalabonos) || '') + "</td>";
                          trt += "</tr>";
                        $('#table_historia_abonos').append(trt);

                        $("#ltotaladeudado").css("display", "inline").text("Total adeudado: $"+format_js(data.adeudado));
                        totalAdeudadoGlobal  = data.adeudado;

               },
               error: function(xhr, status) {
                   alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
               }
           });

  

}
  function abrirModal(numeroDelaOt){
    $.ajax({
               
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    type: 'POST',
                    url: "<?php echo e(route('ordendetrabajo.historial')); ?>",
                    data: {
                        'numerodelaot': numeroDelaOt,
                       
                    },
                    success: function(data) {
                    $("#tabla_servicios_selecionados").empty();
                       $('#modalHistorial').show();
                        console.log(data);
                      $.each(data, function(index, objeto) {

                        var reversedIndex = data.length - index;



                            var tr = "<tr>";
                            tr += "<td>" + reversedIndex+"</td>";

                              // tr += "<td>" + objeto.id + "</td>";
                            tr += "<td>" + (formatearFecha(objeto.fecha_ingreso_actualizacion) || '').toUpperCase() + "</td>";
                       
                             tr += "<td>" + '<a style="cursor:pointer"  onclick="irOt(' + objeto.id + ')"  >' + "REVISAR" + "</a>" +
                                "</td>";
                                // Agrega el enlace con la URL
                                tr += '<td><a href="' + '<?php echo e(route('imprimirot', ['idOT' => ''])); ?>' + objeto.id + '" target="_blank">' +
                                      '<span class="material-symbols-outlined">print</span>' +
                                      '</a></td>';

                            
                            $('#tabla_servicios_selecionados').append(tr);

                            });
                    },
                    error: function(xhr, status) {
                        alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                    }
                });


  }
  function irOt(idOt){

    var baseUrl = window.location.origin; // Obtiene la URL base actual
var url = baseUrl + "/ordendetrabajo/showhistorial/" + idOt; // Combina la URL base con la ruta específica

window.location.href = url; // Redirige a la URL completa
  }
  function cerrarModal(){
    $('#modalHistorial').hide();

  }
  function cerrarModalAbonos(){
    $('#modalHistorialAbonos').hide();
  }



  $(document).ready(function() {
      permitirSoloNumeros("#montoparaabonar");



      $('#buscarData').on('keyup', function() {
          var valorIngresado = $(this).val();
        




          $.ajax({

          headers: {
              'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
          },
          type: 'POST',
          url: "<?php echo e(route('search.ot')); ?>",
          data: {
              'data': valorIngresado,
           
          },
          success: function(response) {
             console.log("datasssssdf");
             console.log(response.data);




          $('#tableOt').empty();
          $('#tableOtGeneral').css("display","none");
          if (valorIngresado != "") {
          
            table="";
              $(response.data).each(function(i, v) {
                  
                      
                  table+= '<tr><td>'  + v.numero_ot  + '</td>'
                  // table+= "'<tr><td> <?php echo e(\App\Models\User::tipoUsuario()); ?> </td>'"

                    

                    +"<?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>"
                    
                        +"<?php if(\App\Models\User::tipoUsuario() != 'secretaria' ): ?>"

                           +'<td>'+v.nombre_sucursal+'</td>'  
                        +"<?php endif; ?>"

                      +'<td>'+v.razon_social+'</td>'  
                      +'<td>'+v.rut+'</td>'  
                      +'<td>'+
                        (v.marca ? v.marca : '') + " "+
                      (v.modelo ? v.modelo : '') + " "+
                      (v.motor ? v.motor : '') + " "+
                      (v.ano ? v.ano : '') + " "+
                      (v.nombre_combustible ? v.nombre_combustible : '') 
                        +'</td>'  

                      +'<td>'+v.nombre_completo+'</td>'  
                      +'<td>'+"$"+format_js(v.total_con_descuentos) +'</td>'  



                      +"<?php endif; ?>"

                      +"<?php if(\App\Models\User::tipoUsuario() == 'operario' ): ?>"
                      +"<td class='td-val'>"+v.marca+"</td>"  
                      +"<td class='td-val'>"+v.modelo+"</td>"  
                      +"<td class='td-val'>"+v.motor+"</td>"  
                      +"<td class='td-val'>"+v.ano+"</td>"  
                      +"<td class='td-val'>"+v.nombre_combustible+"</td>"  

                    
                      +"<?php endif; ?>"
                      


                      // +"<?php if(\App\Models\User::tipoUsuario() == 'operario' ): ?>"
                      // +"<td class='td-val'><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id ?? '')[0]->marca ?? ''); ?></td>"  
                      // +"<td class='td-val'><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id ?? '')[0]->modelo ?? ''); ?></td>" 
                      // +"<td class='td-val'><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id  ?? '')[0]->motor ?? ''); ?></td>"  
                      // +"<td class='td-val'><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id  ?? '')[0]->ano ?? ''); ?></td>"
                      // +"<td class='td-val'><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id  ?? '')[0]->nombrecombustible ?? ''); ?></td>"

                      // +"<?php endif; ?>"
                      


                      +'<td>'+formatearFecha(v.fecha_ingreso)+'</td>'  
                      +'<td>'+formatearFecha(v.fecha_entrega)+'</td>'  
                      +'<td>'+v.descripcionestado+'</td>'  


                      // +'<td>'+v.correo+'</td>'  
                      // +'<td>'+v.nombre_direccion+'</td>'  
                      // +'<td>'+v.des_region+'</td>'  
                      // +'<td>'+v.des_comuna+'</td>'  

                      +'<td>';

                    if(v.descripcionestado == "FACTURADA" || v.descripcionestado == "CANCELADA" ){

                      table+="<?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "superadmin"): ?>";

                  
                      table+= '<a href="<?php echo e(route('ordendetrabajo.showhistorial',['id' => ''])); ?>' + "/"+v.id + '" style="cursor: pointer">'                        
                    +'<span class="material-symbols-outlined">visibility</span></a>'; 
                      table+="<?php endif; ?>";

                    }else{

                      
                      table += '<a href="<?php echo e(route('ordendetrabajo.show', ['id' => ''])); ?>' + "/"+v.id + '" style="cursor: pointer">'                        
       + '<span class="material-symbols-outlined">visibility</span></a>';

                    }




                    table+="<?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>";
                      // table += '<a><span class="material-symbols-outlined">delete</span></a>';

                    if(v.descripcionestado == "FACTURADA" || v.descripcionestado == "CANCELADA" ){
                     }else{

                      table += '<a href="<?php echo e(route('ordendetrabajo.editar', ['id' => ''])); ?>' + "/"+v.id + '" style="cursor: pointer">'                        
                      + '<span class="material-symbols-outlined">edit</span></a>';
                    }

                      // table += '<span class="material-symbols-outlined" style="cursor:pointer"  onclick="abrirModal(<?php echo e($los_datos->numero_ot ?? ''); ?>)" >manage_search</span>';
                      table += '<span class="material-symbols-outlined" style="cursor:pointer" onclick="abrirModal(' + v.numero_ot + ')" >manage_search</span>';

                      // table += '<span class="material-symbols-outlined" style="cursor:pointer" onclick="abrirModalAbonos(<?php echo e($los_datos->numero_ot ?? ''); ?>,<?php echo e($los_datos->id ?? ''); ?>)">paid</span>';
                      // table += '<span class="material-symbols-outlined" style="cursor:pointer" onclick="abrirModalAbonos(<?php echo e($los_datos->numero_ot ?? ''); ?>,' +v.id + ')">paid</span>';
                      table += '<span class="material-symbols-outlined" style="cursor:pointer" onclick="abrirModalAbonos(' + v.numero_ot + ',' + v.id + ')">paid</span>';
                      
                      +'</td></tr>';
                      table+="<?php endif; ?>";
                      
              })
              $('#tableOt').append( table );
          } else {
          $("#tableOtGeneral").css("display","");

              $('#tableOt').empty();

          }


          },
          error: function(xhr, status) {
              alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
          }
          });



         
     

      });



        });

        //ABRIR OTRA URL
        $(document).ready(function() {
    // Verificar si hay un mensaje en la sesión
    var mensaje = '<?php echo e(session("mensaje")); ?>';
    if (mensaje !== '') {
      //  alert(mensaje); // Mostrar el mensaje flash

        // Verificar si hay un ID de orden de trabajo en la sesión
        var idOT = '<?php echo e(session("idOT")); ?>';
        if (idOT !== '') {

          // alert(idOT);
            // Construir la URL para la nueva pestaña
            // http://35.232.42.155:8500/imprimir/ot?idOT=%3AidOT
            var url = '<?php echo e(route("imprimirot", ["idOT" => "laot"])); ?>';
            url = url.replace('laot', idOT);

            // Abrir una nueva pestaña con la URL
            window.open(url, '_blank');
        }
    }
});
function validarDiferenciaAno(fechaInicioId, fechaFinId) {
  // Obtener los valores de los inputs
  var fecha_inicio = new Date($(fechaInicioId).val());
  var fecha_fin = new Date($(fechaFinId).val());

  // Calcular la diferencia en milisegundos
  var diferenciaMilisegundos = fecha_fin - fecha_inicio;

  // Calcular el número de milisegundos en un año
  var milisegundosEnUnAno = 365 * 24 * 60 * 60 * 1000;

  // Verificar si la diferencia es mayor a un año
  if (diferenciaMilisegundos > milisegundosEnUnAno) {
    // Si es mayor a un año, aplicar estilo rojo al input de fecha fin
    $(fechaFinId).css("color", "red");

    $("#textoerror").text("Rango superior a un año calendario, favor de ingresar fechas nuevamente");
    
    return true; // Indicar que la diferencia es mayor a un año
  } else {
    // Si no es mayor a un año, asegurarse de que el estilo rojo se elimine
    $("#textoerror").text("");

    $(fechaFinId).css("color", "");
    return false; // Indicar que la diferencia no es mayor a un año
  }
}
</script>

<script>
  $(function () {
      $('input[name="customDateRange"]').daterangepicker({
          opens: 'left',
          locale: {
              format: 'DD-MM-YYYY',
              applyLabel: 'Aplicar',
              cancelLabel: 'Cancelar',
              fromLabel: 'Desde',
              toLabel: 'Hasta',
              customRangeLabel: 'Personalizado',
              daysOfWeek: ['Do', 'Lu', 'Ma', 'Mi', 'Ju', 'Vi', 'Sa'],
              monthNames: ['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio',
                  'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre'
              ],
              firstDay: 1
          },
          ranges: {
              'Hoy': [moment(), moment()],
              'Esta Semana': [moment().startOf('isoWeek'), moment().endOf('isoWeek')],
              'Este Mes': [moment().startOf('month'), moment().endOf('month')],
              'Mes Pasado': [moment().subtract(1, 'month').startOf('month'), moment()
                  .subtract(1,
                      'month').endOf('month')
              ]
          }
      });

      // Inicializar DataTables
  });
</script>

<script>
$(document).ready(function() {

  // LLamamos la funcion cuando se inicia el sistema
  formatFecha($("#customDateRange").val());
    $('#customDateRange').on('change', function() {
        var valor = $(this).val();

        formatFecha(valor);
        // console.log('Nuevo valor del campo customDateRange:', valor);
        // Aquí puedes realizar otras acciones con el valor capturado
        
    });
});


function formatFecha(fecha){
  // Separar las fechas por el separador '-'
var partes = fecha.split(' - ');

    // Obtener las fechas separadas
    var fechaInicio = partes[0];
    var fechaFin = partes[1];

    // Función para formatear la fecha en dd/mm/yyyy
    function formatearFecha(fecha) {
      var partes = fecha.split('-');
        if (partes.length === 3) {
            return partes[2] + '-' + partes[1] + '-' + partes[0];
        } else {
            return '';
        }
    }

    // Formatear las fechas
    var fechaInicioFormateada = formatearFecha(fechaInicio);
    var fechaFinFormateada = formatearFecha(fechaFin);


    $('#fecha_inicio').val(fechaInicioFormateada);
    $('#fecha_fin').val(fechaFinFormateada);
    // Mostrar los resultados
    var resultado = 'inicio= ' + fechaInicioFormateada + '<br>fin= ' + fechaFinFormateada;
        console.log(resultado);
}
</script>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.sidebar', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH /var/www/html/sistema/resources/views/ordenesdetrabajo/ordenesdetrabajo.blade.php ENDPATH**/ ?>